..
      Copyright 2016 Huawei Technologies India Pvt Limited.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.


      Convention for heading levels in Neutron devref:
      =======  Heading 0 (reserved for the title in a document)
      -------  Heading 1
      ~~~~~~~  Heading 2
      +++++++  Heading 3
      '''''''  Heading 4
      (Avoid deeper levels because they do not render well.)

Command-Line Interface
======================

Neutron client has provided the command-line interfaces (CLI) to realize dynamic routing
services supported by neutron-dynamic-routing project.

Current implementation only supports the command line interfaces for BGP functionality.
For query on what specific :command:`neutron bgp` commands are supported,
enter:

.. code-block:: console

    $ neutron help | grep bgp

.. toctree::
   :maxdepth: 2
   :glob:

   *
